@@ -15,15 +15,15 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.*
  *************************************************************************/
 
-#if !defined(LISTPHYSICALVOLUMES__H)
+#if !defined(LISTPHYSICALVOLUMES_H)
 
-#define LISTPHYSICALVOLUMES__H
+#define LISTPHYSICALVOLUMES_H
 
 #include "ui_listphysicalvolumesbase.h"
 
 #include <core/partition.h>
 
-#include <vector>
+#include <QVector>
 
 #include <QWidget>
 
@@ -50,7 +50,7 @@ public:
 
     void addPartition(const Partition& p, bool checked);
 
-    std::vector<const Partition *> checkedItems();
+    QVector<const Partition *> checkedItems();
 
     QListWidget& listPhysicalVolumes() {
         Q_ASSERT(m_ListPhysicalVolumes);
